@@ -1,4 +1,4 @@
-/* Copyright 2008,2009,2010,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/* Copyright 2008,2009,2010,2012,2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -18,12 +18,14 @@
  */
 #include "KGpgGroupNode.h"
 
+#include "kgpg_debug.h"
 #include "KGpgGroupMemberNode.h"
 #include "KGpgRootNode.h"
 #include "kgpgsettings.h"
 
-#include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
+
+#include <QDebug>
 #include <QFile>
 #include <QStringList>
 #include <QTextStream>
@@ -119,7 +121,10 @@ KGpgGroupNode::KGpgGroupNode(KGpgRootNode *parent, const QString &name, const QS
 	d_ptr(new KGpgGroupNodePrivate(name))
 {
 	foreach (const QString &id, members)
-		new KGpgGroupMemberNode(this, id);
+		if (id.startsWith(QLatin1String("0x")))
+			new KGpgGroupMemberNode(this, id.mid(2));
+		else
+			new KGpgGroupMemberNode(this, id);
 
 	parent->m_groups++;
 }
@@ -138,10 +143,8 @@ KGpgGroupNode::KGpgGroupNode(KGpgRootNode *parent, const QString &name, const KG
 
 KGpgGroupNode::~KGpgGroupNode()
 {
-	KGpgRootNode *root = m_parent->toRootNode();
-
-	if (root != Q_NULLPTR)
-		root->m_groups--;
+	if (parent() != Q_NULLPTR)
+		m_parent->toRootNode()->m_groups--;
 }
 
 KgpgCore::KgpgItemType
@@ -184,7 +187,7 @@ KGpgGroupNode::rename(const QString &newName)
 		return;
 
 	if (index < 0) {
-		kDebug(2100) << "Group " << d->m_name << " not renamed, group does not exist";
+		qCDebug(KGPG_LOG_GENERAL) << "Group " << d->m_name << " not renamed, group does not exist";
 		return;
 	}
 
@@ -250,28 +253,3 @@ KGpgGroupNode::remove()
 	conffile.resize(0);
 	t << lines.join(QLatin1String("\n")) + QLatin1Char('\n');
 }
-
-QStringList
-KGpgGroupNode::readGroups()
-{
-	QStringList groups;
-	QFile qfile(KGpgSettings::gpgConfigPath());
-
-	if (!qfile.exists() || !qfile.open(QIODevice::ReadOnly))
-		return groups;
-
-	QTextStream t(&qfile);
-
-	while (!t.atEnd()) {
-		QString line = t.readLine().simplified().section(QLatin1Char('#'), 0, 0);
-		if (!KGpgGroupNodePrivate::groupPattern().exactMatch(line))
-			continue;
-
-		// remove the "group " at the start
-		line.remove(0, 6);
-		// transform it in a simple space separated list
-		groups.append(line.replace(QLatin1Char('='), QLatin1Char(' ')).simplified());
-	}
-
-	return groups;
-}
