@@ -18,12 +18,12 @@
 #ifndef KGPGDETAILEDCONSOLE_H
 #define KGPGDETAILEDCONSOLE_H
 
-#include <KDialog>
+#include <QDialog>
 
-class KgpgDetailedInfo : public KDialog
+class KgpgDetailedInfo : public QDialog
 {
 public:
-	explicit KgpgDetailedInfo(QWidget *parent = 0, const QString &boxLabel = QString(),
+	explicit KgpgDetailedInfo(QWidget *parent = Q_NULLPTR, const QString &boxLabel = QString(),
 			const QString &errormessage = QString(), const QStringList &keysList = QStringList(),
 			const QString &caption = QString());
 };
