@@ -10,21 +10,19 @@
 #ifndef KGPGMD5WIDGET_H
 #define KGPGMD5WIDGET_H
 
-#include <KDialog>
-#include <KUrl>
-
-#include <kgpgcompiler.h>
+#include <QDialog>
+#include <QUrl>
 
 class QLabel;
 
 class KLed;
 
-class Md5Widget : public KDialog
+class Md5Widget : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit Md5Widget(QWidget *parent = Q_NULLPTR, const KUrl &url = KUrl());
+    explicit Md5Widget(QWidget *parent = Q_NULLPTR, const QUrl &url = QUrl());
 
 public slots:
     void slotApply();
