@@ -17,16 +17,16 @@
 
 #include <QSortFilterProxyModel>
 
-#include <KDialog>
+#include <QDialog>
 
 #include "core/kgpgkey.h"
+#include "model/kgpgsearchresultmodel.h"
 #include "ui_searchres.h"
 #include "ui_keyserver.h"
 
 class KGpgKeyserverSearchTransaction;
 class KeyListProxyModel;
 class KGpgItemModel;
-class KGpgSearchResultModel;
 
 class keyServerWidget : public QWidget, public Ui::keyServerWidget
 {
@@ -48,7 +48,7 @@ public:
     }
 };
 
-class KeyServer : public KDialog
+class KeyServer : public QDialog
 {
 	Q_OBJECT
 
@@ -75,7 +75,13 @@ public:
 	void startImport(const QStringList &keys, QString server = QString(), const QString &proxy = QString());
 
 signals:
+	/**
+	 * @brief emitted when importing keys succeeded
+	 *
+	 * This is only emitted when at least one key has been imported.
+	 */
 	void importFinished(QStringList);
+
 	/**
 	 * @brief importing failed
 	 *
@@ -111,11 +117,12 @@ private slots:
 	void slotSearchResult(int result);
 	void slotSearch();
 	void slotSetFilterString(const QString &expression);
+	void slotUpdateLabelOnFilterChange();
 
 private:
 	QString m_readmessage;
 
-	KDialog *m_dialogserver;
+	QDialog *m_dialogserver;
 	KGpgKeyserverSearchTransaction *m_searchproc;
 
 	keyServerWidget *page;
@@ -124,8 +131,7 @@ private:
 	bool m_autoclose;
 	QString expattr;
 
-	KGpgSearchResultModel *m_resultmodel;
-	QSortFilterProxyModel m_filtermodel;
+	KGpgSearchResultModel m_resultmodel;
 
 	KeyListProxyModel *m_itemmodel;
 };
